==> react-user-feedback-1.0.2.tgz: package/src/locales/Locale.ts <==
export interface FeedbackLocale {
    back: string;
    bugReported: string;
    cancel: string;
    close: string;
    describeBug: string;
    describeBugUrgentCases: string;
    describeReportBug: string;
    directInfluence: string;
    email: string;
    enterFeedback: string;
    feedback: string;
    feedbackSent: string;
    getSupport: string;
    helpUsImproveHCC:string;
    howIsConsoleExperience: string;
    joinMailingList: string;
    informRedhatDirection: string;
    informDirectionDescription: string;
    learnAboutResearchOpportunities: string;
    openSupportCase: string;
    problemProcessingRequest: string;
    redHatSupport: string;
    reportABug: string;
    responseSent:string;
    researchOpportunities: string;
    shareFeedback: string;
    shareYourFeedback:string;
    somethingWentWrong: string;
    submitFeedback: string;
    tellAboutExperience: string;
    teamWillReviewBug: string;
    thankYouForFeedback: string;
    thankYouForInterest: string;
    userResearchTeam:string;
    weNeverSharePersonalInformation: string;
}

export const defaultFeedback : FeedbackLocale =  {
    getSupport: "Get help from Red Hat support.",
    back: "Back",
    bugReported: "Bug Reported",
    cancel: "Cancel",
    close: "Close",
    describeBug: "Describe the bug you encountered. For urgent issues, open a support case instead.",
    describeBugUrgentCases: "Describe the bug you encountered. For urgent issues, open a support case instead.",
    describeReportBug: "Describe the bug you encountered. Include where it is located and what action caused it. If this issue is urgent or blocking your workflow,",
    directInfluence: ", your feedback will directly influence the future of Red Hat’s products. Opt in below to hear about future research opportunities via email.",
    email: "Email",
    enterFeedback: "Enter your feedback",
    feedback: "Feedback",
    feedbackSent: "Feedback Sent",
    helpUsImproveHCC: "Help us improve the Red Hat Hybrid Cloud Console.",
    howIsConsoleExperience: "What has your console experience been like so far?",
    joinMailingList: "Join mailing list",
    informDirectionDescription: "By participating in feedback sessions, usability tests, and interviews with our",
    informRedhatDirection: "Inform the direction of Red Hat",
    learnAboutResearchOpportunities: "Learn about opportunities to share your feedback with our User Research Team.",
    openSupportCase: "Open a support case",
    problemProcessingRequest: "There was a problem processing the request. Try reloading the page. If the problem persists, contact",
    redHatSupport: "Red Hat support",
    reportABug: "Report a bug",
    responseSent: "Response sent",
    researchOpportunities: "Yes, I would like to hear about research opportunities",
    shareFeedback: "Share feedback",
    shareYourFeedback: "Share your feedback with us!",
    somethingWentWrong: "Something went wrong",
    submitFeedback:  "Submit feedback",
    teamWillReviewBug: "We appreciate your feedback and our team will review your report shortly",
    tellAboutExperience: "Tell us about your experience",
    thankYouForFeedback: "Thank you, we appreciate your feedback.",
    thankYouForInterest: "Thank you for your interest in user research. You have been added to our mailing list.",
    userResearchTeam: "User Research Team",
    weNeverSharePersonalInformation: "We never share your personal information, and you can opt out at any time.",
}

==> react-user-feedback-5.0.0.tgz: package/src/locales/Locale.ts <==
export interface FeedbackLocale {
    back: string;
    bugReported: string;
    cancel: string;
    close: string;
    describeBug: string;
    describeBugUrgentCases: string;
    describeReportBug: string;
    directInfluence: string;
    email: string;
    enterFeedback: string;
    feedback: string;
    feedbackSent: string;
    support: string;
    helpUsImproveHCC:string;
    howIsConsoleExperience: string;
    joinMailingList: string;
    informDirection: string;
    informDirectionDescription: string;
    learnAboutResearchOpportunities: string;
    openSupportCase: string;
    problemProcessingRequest: string;
    getSupport: string;
    reportABug: string;
    responseSent:string;
    researchOpportunities: string;
    shareFeedback: string;
    shareYourFeedback:string;
    somethingWentWrong: string;
    submitFeedback: string;
    tellAboutExperience: string;
    teamWillReviewBug: string;
    thankYouForFeedback: string;
    thankYouForInterest: string;
    userResearchTeam:string;
    weNeverSharePersonalInformation: string;
}

export const defaultFeedback : FeedbackLocale =  {
    getSupport: "Get help and support.",
    back: "Back",
    bugReported: "Bug Reported",
    cancel: "Cancel",
    close: "Close",
    describeBug: "Describe the bug you encountered. For urgent issues, open a support case instead.",
    describeBugUrgentCases: "Describe the bug you encountered. For urgent issues, open a support case instead.",
    describeReportBug: "Describe the bug you encountered. Include where it is located and what action caused it. If this issue is urgent or blocking your workflow,",
    directInfluence: ", your feedback will directly influence the future of our products. Opt in below to hear about future research opportunities via email.",
    email: "Email",
    enterFeedback: "Enter your feedback",
    feedback: "Feedback",
    feedbackSent: "Feedback Sent",
    helpUsImproveHCC: "Help us improve our products by sharing your feedback",
    howIsConsoleExperience: "What has your console experience been like so far?",
    joinMailingList: "Join mailing list",
    informDirectionDescription: "By participating in feedback sessions, usability tests, and interviews with our",
    informDirection: "Inform the direction of products",
    learnAboutResearchOpportunities: "Learn about opportunities to share your feedback with our User Research Team.",
    openSupportCase: "Open a support case",
    problemProcessingRequest: "There was a problem processing the request. Try reloading the page. If the problem persists, contact",
    support: "Support",
    reportABug: "Report a bug",
    responseSent: "Response sent",
    researchOpportunities: "Yes, I would like to hear about research opportunities",
    shareFeedback: "Share feedback",
    shareYourFeedback: "Share your feedback with us!",
    somethingWentWrong: "Something went wrong",
    submitFeedback:  "Submit feedback",
    teamWillReviewBug: "We appreciate your feedback and our team will review your report shortly",
    tellAboutExperience: "Tell us about your experience",
    thankYouForFeedback: "Thank you, we appreciate your feedback.",
    thankYouForInterest: "Thank you for your interest in user research. You have been added to our mailing list.",
    userResearchTeam: "User Research Team",
    weNeverSharePersonalInformation: "We never share your personal information, and you can opt out at any time.",
}
